==> apache-opendal-integrations-dav-server-0.0.7-src.tar.gz: apache-opendal-integrations-dav-server-0.0.7-src/core/src/types/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

mod mode;
pub use mode::EntryMode;

mod buffer;
pub use buffer::Buffer;

mod entry;
pub use entry::Entry;

mod metadata;
pub use metadata::Metadata;
pub use metadata::Metakey;

mod read;
pub use read::*;

mod blocking_read;
pub use blocking_read::*;

mod write;
pub use write::*;

mod blocking_write;
pub use blocking_write::*;

mod list;
pub use list::BlockingLister;
pub use list::Lister;

mod execute;
pub use execute::*;

mod operator;
pub use operator::operator_functions;
pub use operator::operator_futures;
pub use operator::BlockingOperator;
pub use operator::Operator;
pub use operator::OperatorBuilder;
pub use operator::OperatorInfo;

mod builder;
pub use builder::Builder;
pub use builder::Configurator;

mod error;
pub use error::Error;
pub use error::ErrorKind;
pub use error::Result;

mod scheme;
pub use scheme::Scheme;

mod capability;
pub use capability::Capability;

mod context;
pub(crate) use context::*;

==> apache-opendal-integrations-dav-server-0.6.3-src.tar.gz: apache-opendal-integrations-dav-server-0.6.3-src/core/src/types/mod.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

mod mode;
pub use mode::EntryMode;

mod buffer;
pub use buffer::Buffer;

mod entry;
pub use entry::Entry;

mod metadata;
pub use metadata::Metadata;

mod read;
pub use read::*;

mod write;
pub use write::*;

mod list;
pub use list::Lister;

mod delete;
pub use delete::*;

mod execute;
pub use execute::*;

mod operator;
pub use operator::operator_futures;
pub use operator::Operator;
pub use operator::OperatorBuilder;
pub use operator::OperatorInfo;

mod builder;
pub use builder::Builder;
pub use builder::Configurator;

mod error;
pub use error::Error;
pub use error::ErrorKind;
pub use error::Result;

mod scheme;
pub use scheme::Scheme;

mod capability;
pub use capability::Capability;

pub mod options;

mod context;
pub(crate) use context::*;
